SPOOL RESULTAT.TXT
SET PAGESIZE 66
SET LINESIZE 120
SET ECHO ON
SET FEEDBACK ON
SET HEADING ON

/************************************************************************************
*                                                                                   *
*   orastats.sql       SILVERRUN ENTERPRISE BPM/RDM 2.8        Grandite             *
*   27-06-2003         SILVERRUN ENTREPRISE DFD/MRD 2.8        Grandite             *
*                                                                                   *
*************************************************************************************
*                                                                                   *
*   Connect under:                              Se connecter sous:                  *
*                                                                                   *
*   sys.                                        sys.                                *
*                                                                                   *
*************************************************************************************
*                                                                                   *
*   Description:                                Description:                        *
*                                                                                   *
*   Procedure detecting any potential           Routine de prise de statistiques    *
*   problems with Oracle's version 7            permettant la detection de          *
*   configuration.                              problemes potentiels pour la        *
*                                               configuration d'Oracle version 7.   *
*                                                                                   *
*   This procedure should be executed           Cette routine devrait etre lancee   *
*   after the system is running for the         apres que le systeme soit demarre   *
*   longest possible period.                    et ce pour la periode la plus       *
*                                               longue possible.                    *
*                                                                                   *
*   By: Bruno Cloutier,                         Par: Bruno Cloutier,                *
*   Informatique DICA inc.                      Informatique DICA inc.              *
*                                                                                   *
************************************************************************************/

Rem *********************************************************************************
Rem
Rem Prise en note de la date et heure de lancement de la routine.
Rem
Rem Extracting the date and time of execution of the procedure.
Rem

SELECT TO_CHAR(SYSDATE,'DD-MM-YYYY HH24:MI:SS') "START TIME"
FROM DUAL; 

Rem *********************************************************************************
Rem
Rem  Obtention des statistiques du systeme depuis son demarrage.
Rem  (User calls vs Recursive calls)
Rem  (free buffer inspected: Si valeur haute peut decroitre db_block_max_scan_cnt.
Rem                          Nombre de blocs saute avant de trouver bloc libre)
Rem  (dbwr free needed: Devrait etre 0. Sinon trouve pas bloc libre)
Rem  (dbwr checkpoints: Nombre de checkpoint complete par dbwr)
Rem  (redo log space requests: Si different de 0, le log buffer est trop petit et des
Rem                            processus attendent pour obtenir de l'espace)
Rem  (sort (disk): Nombre de tri sur disque parce que sort_area_size
Rem                n'etait pas suffisant)
Rem  (sort (memory): Nombre de tri en memoire)
Rem 
Rem 
Rem  Systems statistics obtained since startup.
Rem  (User calls vs Recursive calls)
Rem  (free buffer inspected: If high value may decrease db_block_max_scan_cnt.
Rem                          Number of blocks skipped before finding a free block)
Rem  (dbwr free needed: Should be 0. Else doesn't find free block)
Rem  (dbwr checkpoints: Number of checkpoints completed by dbwr)
Rem  (redo log space requests: If different from 0, the log buffer is
Rem                            too small and processes wait to obtain space. 
Rem  (sort (disk): Number of sort on disk because sort_area_size was not sufficient)
Rem  (sort (memory): Number of sort in memory)
Rem 
Rem

COL NAME FORMAT A38
COL VALUE FORMAT 99999999999
SELECT NAME, 
       VALUE
FROM V$SYSSTAT;

Rem *********************************************************************************
Rem
Rem Obtention des statistiques sur l'utilisation de la cache des informations du
Rem dictionnaire des donnees depuis le demarrage d'Oracle.
Rem (<10-15% Ok)
Rem
Rem Obtaining statistics on the use of the cache 
Rem with the informations contained in the data dictionary since
Rem Oracle was started.
Rem (<10-15% Ok)
Rem

COL RATIO FORMAT 999.99
SELECT SUM(GETS),
       SUM(GETMISSES),
       SUM(GETMISSES)/SUM(GETS) RATIO
FROM V$ROWCACHE;

Rem *********************************************************************************
Rem
Rem Calcul du ratio de succes de la cache de donnees depuis qu'Oracle est demarre.
Rem (<60-70 % probleme potentiel)
Rem (>90 % pourrait probablement liberer de la memoire)
Rem (=70-80 % Ok)
Rem
Rem Calculating the ratio of sucess of data cache since Oracle is running.
Rem (<60-70 %  potential problems)
Rem (>90 % could probably free some memory)
Rem (=70-80 % Ok)
Rem

SELECT (CUR.VALUE + CON.VALUE - PHYS.VALUE)
      /(CUR.VALUE + CON.VALUE) RATIO
FROM V$SYSSTAT CUR, V$SYSSTAT CON, V$SYSSTAT PHYS
WHERE CUR.NAME = 'db block gets'
  AND CON.NAME = 'consistent gets'
  AND PHYS.NAME = 'physical reads';

Rem *********************************************************************************
Rem
Rem Calcul du ratio d'enonces SQL ou PL/SQL qui ne se retrouvaient pas
Rem dans la cache ("cache misses") durant l'execution.
Rem (> 1% indique un probeme potentiel)
Rem S'il n'y a jamais de "cache misses", le parametre CURSOR_SPACE_FOR_TIME
Rem peut etre mis a TRUE afin de liberer la cache seulement quand tous les 
Rem cursor associes a cet enonce sont fermes. Donc, il n'y pas de
Rem verification pour des enonces identiques.
Rem Ceci n'est pas recommande s'il y a emission de requete ad-hoc, car il
Rem risque de ne plus avoir d'espace pour du "parsing".
Rem
Rem
Rem Calculating the ratio of SQL or PL/SQL statements that where not found in
Rem the cache ("cache misses") during the execution.
Rem (> 1% indicates potential problem)
Rem If there is never any "cache misses", the parameter CURSOR_SPACE_FOR_TIME
Rem could be set to TRUE to free the cache only when all the 
Rem cursors associated to that statement are closed. 
Rem So there is no verification for identical statements.
Rem This is not recommended if there is a ad-hoc query,  
Rem because there might not have enough space for the parsing.
Rem

SELECT SUM(PINS) "NB EXECUTIONS", 
       SUM(RELOADS) "NB MISSED",
       SUM(RELOADS)/SUM(PINS) "RATIO"
FROM V$LIBRARYCACHE;

Rem *********************************************************************************
Rem
Rem Obtention des attentes pour la contention des  
Rem rollback segments depuis qu'Oracle est demarre.
Rem (ratio > 1 % indique un probleme potentiel)
Rem
Rem
Rem Obtaining waits for the contention of the  
Rem rollback segments since Oracle is started.
Rem (ratio > 1 % indicates a potential problem)
Rem

SELECT W.CLASS, 
       W.COUNT NBWAITS,
       W.COUNT/(CUR.VALUE+CON.VALUE) RATIO
FROM V$WAITSTAT W, V$SYSSTAT CUR, V$SYSSTAT CON
WHERE W.CLASS IN ('system undo header',
                  'system undo block',
                  'undo block',
                  'undo header')
  AND CUR.NAME = 'db block gets'
  AND CON.NAME = 'consistent gets';

Rem *********************************************************************************
Rem
Rem Verification de la contention aux "latches" du Redo Log buffer
Rem depuis qu'Oracle est demarre.
Rem (Redo allocation: misses/gets > 1 % indique trop de petites
Rem                   transactions. Des systeme avec plusieurs CPU
Rem                   peuvent etre capable de tolerer davantage sans
Rem                   impact sur la performance)
Rem (Redo copy: Si immediate_misses/(immediate_misses_immediate_gets) > 1%, 
Rem             log_simultaneous_copies devrait etre augmente ou peut-etre
Rem             log_prebuild_threshold pourrait etre augmente)
Rem
Rem Verification of the contention at the latches of the Redo Log buffer
Rem since Oracle is started.
Rem (Redo allocation: misses/gets > 1 % indicates too many small transactions.
Rem                   Systems with many CPU could tolerate
Rem                   more without an impact on the performance)
Rem (Redo copy: If immediate_misses/(immediate_misses_immediate_gets) > 1%, 
Rem             log_simultaneous_copies should be increased or
Rem             log_prebuild_threshold could be increased)
Rem

SELECT SUBSTR(N.NAME,1,20) NAME,
       L.GETS,
       L.MISSES,
       DECODE(L.GETS,0,0,L.MISSES/L.GETS) "MISSES/GETS",
       L.IMMEDIATE_GETS,
       L.IMMEDIATE_MISSES,
       DECODE(L.IMMEDIATE_MISSES+L.IMMEDIATE_GETS,0,0,
              L.IMMEDIATE_MISSES/(L.IMMEDIATE_MISSES+L.IMMEDIATE_GETS))
       "MISSES/(MISSES+GETS)",
       L.SLEEPS
FROM V$LATCHNAME N, V$LATCH L
WHERE N.LATCH# = L.LATCH#
  AND N.NAME IN ('redo copy','redo allocation');

Rem *********************************************************************************
Rem
Rem Affichage de l'activite des dispatchers
Rem (Total busy rate > 50% devrait considerer ajouter des dispatchers)
Rem
Rem Display dispatchers activities.
Rem (Total busy rate > 50% should consider adding dispatchers)
Rem

SELECT NETWORK "PROTOCOL",
       SUM(BUSY)/(SUM(BUSY) + SUM(IDLE)) "TOTAL BUSY RATE"
FROM V$DISPATCHER
GROUP BY NETWORK;

Rem *********************************************************************************
Rem
Rem Affichage du temps d'attente moyen d'une reponse dans une queue de reponse.
Rem (Le temps d'attente a tendance a croitre, on devrait considerer
Rem  l'ajout de dispatchers)
Rem
Rem
Rem Displaying average wait time for an answer in the queue 
Rem (Wait time has a tendency to increase in size, we should consider 
Rem  adding some dispatchers)
Rem

SELECT D.NETWORK "PROTOCOL",
       DECODE(SUM(Q.TOTALQ), 0, 'NO RESPONSES',
              SUM(Q.WAIT)/SUM(Q.TOTALQ) || ' HUNDREDTH OF A SECOND') 
              "AVERAGE WAIT TIME"
FROM V$QUEUE Q, V$DISPATCHER D
WHERE Q.TYPE = 'DISPATCHER'
  AND Q.PADDR = D.PADDR
GROUP BY NETWORK;

Rem *********************************************************************************
Rem
Rem Affichage du temps d'attente moyen d'une demande dans une queue 
Rem de demande.
Rem (Le temps d'attente a tendance a croitre, on devrait considerer
Rem l'ajout de "servers" si on a atteint MTS_MAX_SERVERS)
Rem 
Rem  Displaying average wait time for a query in the queue 
Rem  (Wait time has a tendency to increase in size, we should consider 
Rem  adding servers if we reach MTS_MAX_SERVERS)
Rem 

SELECT DECODE(TOTALQ, 0, 'NO REQUESTS',
       WAIT/TOTALQ || ' HUNDREDTH OF A SECOND')
       "AVERAGE WAIT TIME"
FROM V$QUEUE
WHERE TYPE = 'COMMON';

Rem *********************************************************************************
Rem
Rem Affichage de la contention du a des INSERT concourants.
Rem (Si le ratio > 1% on devrait considerer l'ajout de free list)
Rem
Rem
Rem Displaying the contention due to concurrent INSERTS.
Rem (If ratio > 1% we should consider adding a free list)
Rem

SELECT W.CLASS, W.COUNT, W.COUNT/(CUR.VALUE+CON.VALUE) RATIO
FROM V$WAITSTAT W, V$SYSSTAT CUR, V$SYSSTAT CON
WHERE W.CLASS = 'free list'
  AND CUR.NAME = 'db block gets' 
  AND CON.NAME = 'consistent gets';

Rem *********************************************************************************
Rem
Rem Affiche l'activite des transactions sur les rollback segments.
Rem (Si ratio > 0, on devrait normalement ajouter des rollback segments)
Rem 
Rem Displaying transaction activities on the rollback segments.
Rem (If ratio > 0, we should normally add some rollback segments)
Rem 

SELECT EXTENTS,
       RSSIZE,
       WRITES,
       GETS,
       XACTS,
       (WAITS * 100)/(DECODE(GETS,0,1,NULL,1,GETS)) RATIO
FROM V$ROLLSTAT;

Rem *********************************************************************************
Rem
Rem Affiche l'activite des fichiers de donnees depuis le demarrage d'Oracle.
Rem Le parametre TIMED_STATISTICS doit etre a TRUE pour les statistiques de temps.
Rem Si la charge est pres de la capacite du disque, ceci peut indiquer un emcombrement.
Rem (Exemple: 40 ou plus d'acces par seconde est souvent excessif pour 
Rem           pour certains disques Unix et VMS)
Rem
Rem Displaying the activity of the data files since Oracle startup.
Rem The parameter TIMED_STATISTICS must be TRUE for the time statistics.
Rem If the disk capacity has a big charge, this could indicate an obstruction.
Rem (For example: 40 or more accesses per second is quite 
Rem               excessive for some Unix and VMS disks)
Rem

COL NAME FORMAT A50
SELECT DF.NAME,
       FS.PHYRDS,
       FS.PHYWRTS,
       FS.PHYBLKRD,
       FS.PHYBLKWRT,
       FS.READTIM,
       FS.WRITETIM
FROM V$DATAFILE DF, V$FILESTAT FS
WHERE DF.FILE# = FS.FILE#;

Rem *********************************************************************************
Rem
Rem Affichage des segments temporaires qui peuvent exister lors du fonctionnement.
Rem
Rem Displaying temporary segments which could exist while running the application.
Rem

SELECT SEGMENT_NAME, BYTES, TABLESPACE_NAME
FROM DBA_SEGMENTS
WHERE SEGMENT_TYPE='TEMPORARY';

Rem *********************************************************************************
Rem
Rem Affichage des fichiers redo log.
Rem
Rem Displaying redo log files.
Rem

SELECT * 
FROM V$LOGFILE;

Rem *********************************************************************************
Rem
Rem Affichage des fichiers de donnees;
Rem
Rem Displaying data files;
Rem

COL FILE_NAME FORMAT A50
SELECT * 
FROM DBA_DATA_FILES;

Rem *********************************************************************************
Rem
Rem Affichage des tablespaces
Rem
Rem Displaying tablespaces
Rem

SELECT * 
FROM DBA_TABLESPACES;

Rem *********************************************************************************
Rem
Rem Affichage de l'espace libre de la base de donnees.
Rem
Rem Displaying free space on the database.
Rem

SELECT TABLESPACE_NAME, 
       SUM(BYTES)
FROM DBA_FREE_SPACE
GROUP BY TABLESPACE_NAME;

Rem *********************************************************************************
Rem
Rem Affichage du SGA
Rem
Rem Displaying the SGA
Rem

SELECT *
FROM V$SGA;

Rem *********************************************************************************
Rem
Rem Affichage des parametres du init.ora actif.
Rem
Rem Parametres a verifier:
Rem  optimizer_mode : activation du "cost based optimizer"
Rem  log_buffer: Grosseur du tampon du "redo log"
Rem  database_buffer: Grosseur de la cache des donnees
Rem  shared_spool_size: Grosseur de la cache des SQL et du dictionnaire
Rem                     de donnees
Rem  pre_page_sga: Mise en memoire du SGA lors du demarrage de l'instance.
Rem                Accroit le temps de demarrage mais reduit le temps
Rem                d'allocation dynamique de la memoire.
Rem
Rem
Rem Displaying init.ora current parameters.
Rem
Rem Parameters to verify:
Rem  optimizer_mode : activation of "cost based optimizer"
Rem  log_buffer: Size of the "redo log" buffer
Rem  database_buffer: Size of the data cache 
Rem  shared_spool_size: Size of the SQL cache and of the data dictionary
Rem  pre_page_sga: Load in memory the SGA when starting the instance.
Rem                Increases the time of startup but reduces the time of dynamic
Rem                allocation of the memory.
Rem

COL VALUE FORMAT A60
SELECT NAME,
       VALUE
FROM V$PARAMETER
ORDER BY NAME;

Rem *********************************************************************************
Rem
Rem Affichage des "segments" ayant plus de 7 "extents".
Rem
Rem Displaying the segments which have more than 7 extents.
Rem

SELECT SEGMENT_NAME, SEGMENT_TYPE, TABLESPACE_NAME, EXTENTS
FROM DBA_SEGMENTS
WHERE EXTENTS>7
ORDER BY EXTENTS DESC;

Rem *********************************************************************************
Rem
Rem Fin de la routine.
Rem
Rem End of procedure.
Rem

SPOOL OFF
